@@ -7,7 +7,7 @@ cor <- 0.8
 eps <- 0.25 # correlation between relevant and irrelevant variable
 S11 <- toeplitz(cor^(0:(80-1))) ## Toeplitz correlation for irrelevant variable
 S22 <- matrix(cor,10,10) ## bloc correlation bewteen relevant variables
-diag(S22) <- 1 
+diag(S22) <- 1
 Sigma <- bdiag(S11,S22,S22) + eps
 
 ## Build a vector of label for true nonzeros
@@ -35,6 +35,6 @@ print(fit)
 ## Call to stability selection function, 200 subsampling
 stab <- stability(x,y, subsamples=200, lambda2=1, min.ratio=1e-2)
 ## plot the stability path
-plot(stab, labels=labels, cutoff=0.75, PFER=1)
+plot(stab, labels=labels, nvar=20)
 ## a quick summary of the fit
 print(stab)
