@@ -30,7 +30,7 @@ SEXP bounded_reg(SEXP X        ,
 
   // disable messages being printed to the err2 stream (armadillo's runtime error)
   std::ostream nullstream(0);
-  set_stream_err2(nullstream);
+  set_cerr_stream(nullstream);
 
   // Reading input variables
   bool intercept  = as<bool>   (INTERCEPT)   ; // boolean for intercept mode
